@@ -13,22 +13,19 @@ from __future__ import absolute_import
 __all__ = ['UserBase', 'UserManager']
 
 import urlparse
-from datetime import datetime
 from flask import g, current_app, json, session
-from sqlalchemy import Column, Integer, String, DateTime, Unicode, UnicodeText
+from sqlalchemy import Column, String, Unicode, UnicodeText
 from sqlalchemy.orm import deferred, undefer
 from sqlalchemy.ext.declarative import declared_attr
 from flask.ext.lastuser import UserInfo
+from coaster.sqlalchemy import BaseMixin
 
 
-class UserBase(object):
+class UserBase(BaseMixin):
     """
     Base class for user definition.
     """
     __tablename__ = 'user'
-    id = Column(Integer, primary_key=True)
-    created_at = Column(DateTime, default=datetime.utcnow, nullable=False)
-    updated_at = Column(DateTime, default=datetime.utcnow, onupdate=datetime.utcnow, nullable=False)
     userid = Column(String(22), unique=True, nullable=False)
     username = Column(Unicode(80), unique=True, nullable=True)  # Usernames are optional
     fullname = Column(Unicode(80), default=u'', nullable=False)
@@ -132,7 +129,7 @@ class UserManager(object):
 
         # Watch for username/email conflicts. Remove from any existing user
         # that have the same username or email, for a conflict can only mean
-        # that we didn't hear of this change when it happened in LastUser
+        # that we didn't hear of this change when it happened in Lastuser
         olduser = self.usermodel.query.filter_by(username=user.username).first()
         if olduser is not None and olduser.id != user.id:
             olduser.username = None
